@@ -1,7 +1,7 @@
 /*
  * $RCSfile: receive_tcp_socket.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.19 $ $Date: 2005/08/31 14:50:18 $ $Author: christian $
+ * @version $Revision: 1.30 $ $Date: 2006/06/20 16:16:29 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @description
  */
@@ -28,6 +28,8 @@
 #ifndef RECEIVE_TCP_SOCKET_SOURCE
 #define RECEIVE_TCP_SOCKET_SOURCE
 
+#ifdef LINUX_OPERATING_SYSTEM
+
 #include <arpa/inet.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -35,17 +37,17 @@
 #include <stdio.h>
 #include <pthread.h>
 #include <unistd.h>
-#include "../../applicator/create.c"
+#include "../../applicator/receive/receive_file_system.c"
 #include "../../globals/constants/abstraction_constants.c"
 #include "../../globals/constants/channel_constants.c"
 #include "../../globals/constants/character_constants.c"
-#include "../../globals/constants/constant.c"
 #include "../../globals/constants/escape_code_constants.c"
 #include "../../globals/constants/integer_constants.c"
 #include "../../globals/constants/log_constants.c"
 #include "../../globals/constants/model_constants.c"
 #include "../../globals/constants/name_constants.c"
 #include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/tcp_socket_constants.c"
 #include "../../globals/variables/variables.c"
 #include "../../memoriser/accessor/compound_accessor.c"
 #include "../../memoriser/accessor/internal_memory_accessor.c"
@@ -58,7 +60,7 @@
 //
 
 /**
- * Creates a model.
+ * Receives a file system model.
  *
  * @param p0 the destination
  * @param p1 the destination count
@@ -70,7 +72,7 @@
  * @param p7 the source channel
  * @param p8 the source channel count
  */
-void create(void* p0, void* p1, void* p2, void* p3, void* p4,
+void receive_file_system_model(void* p0, void* p1, void* p2, void* p3, void* p4,
     void* p5, void* p6, void* p7, void* p8);
 
 /**
@@ -100,7 +102,7 @@ void get_request_method(char* req, int* req_count, char** req_method, int* req_m
 
         get_array_elements(req, req_method_count, (void*) &e, (void*) CHARACTER_ARRAY);
 
-        if (*e == *SPACE_CHARACTER) {
+        if (*e == *SPACE_ASCII_CHARACTER) {
 
             // Reached end of request method.
             break;
@@ -148,7 +150,7 @@ void get_url_basename_from_request(char* req, int* req_count, char** urlbase, in
         get_array_elements(req, (void*) &req_index, (void*) &e, (void*) CHARACTER_ARRAY);
 
         // Check of ending the paramaters.
-        if ((start_urlbase_flag == 1) && ((*e == *SPACE_CHARACTER) || (*e == *QUESTION_MARK_CHARACTER))) {
+        if ((start_urlbase_flag == 1) && ((*e == *SPACE_ASCII_CHARACTER) || (*e == *QUESTION_MARK_ASCII_CHARACTER))) {
 
             break;
         }
@@ -165,7 +167,7 @@ void get_url_basename_from_request(char* req, int* req_count, char** urlbase, in
         }
 
         // Check of beginning the paramaters.
-        if (*e == *SOLIDUS_CHARACTER) {
+        if (*e == *SOLIDUS_ASCII_CHARACTER) {
 
             // Begin from the parameters.
             start_urlbase_flag = 1;
@@ -203,7 +205,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) SPACE_CHARACTER;
+                    *dest = (char*) SPACE_ASCII_CHARACTER;
                 }
             }
 
@@ -214,7 +216,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) LESS_THAN_SIGN_CHARACTER;
+                    *dest = (char*) LESS_THAN_SIGN_ASCII_CHARACTER;
                 }
             }
 
@@ -225,7 +227,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) GREATER_THAN_SIGN_CHARACTER;
+                    *dest = (char*) GREATER_THAN_SIGN_ASCII_CHARACTER;
                 }
             }
 
@@ -236,7 +238,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) NUMBER_SIGN_CHARACTER;
+                    *dest = (char*) NUMBER_SIGN_ASCII_CHARACTER;
                 }
             }
 
@@ -247,7 +249,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) PERCENT_SIGN_CHARACTER;
+                    *dest = (char*) PERCENT_SIGN_ASCII_CHARACTER;
                 }
             }
 
@@ -258,7 +260,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) LEFT_CURLY_BRACKET_CHARACTER;
+                    *dest = (char*) LEFT_CURLY_BRACKET_ASCII_CHARACTER;
                 }
             }
 
@@ -269,7 +271,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) RIGHT_CURLY_BRACKET_CHARACTER;
+                    *dest = (char*) RIGHT_CURLY_BRACKET_ASCII_CHARACTER;
                 }
             }
 
@@ -280,7 +282,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) VERTICAL_LINE_CHARACTER;
+                    *dest = (char*) VERTICAL_LINE_ASCII_CHARACTER;
                 }
             }
 
@@ -291,7 +293,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) REVERSE_SOLIDUS_CHARACTER;
+                    *dest = (char*) REVERSE_SOLIDUS_ASCII_CHARACTER;
                 }
             }
 
@@ -302,7 +304,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) CIRCUMFLEX_ACCENT_CHARACTER;
+                    *dest = (char*) CIRCUMFLEX_ACCENT_ASCII_CHARACTER;
                 }
             }
 
@@ -313,7 +315,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) TILDE_CHARACTER;
+                    *dest = (char*) TILDE_ASCII_CHARACTER;
                 }
             }
 
@@ -324,7 +326,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) LEFT_SQUARE_BRACKET_CHARACTER;
+                    *dest = (char*) LEFT_SQUARE_BRACKET_ASCII_CHARACTER;
                 }
             }
 
@@ -335,7 +337,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) RIGHT_SQUARE_BRACKET_CHARACTER;
+                    *dest = (char*) RIGHT_SQUARE_BRACKET_ASCII_CHARACTER;
                 }
             }
 
@@ -346,7 +348,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) GRAVE_ACCENT_CHARACTER;
+                    *dest = (char*) GRAVE_ACCENT_ASCII_CHARACTER;
                 }
             }
 
@@ -357,7 +359,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) SEMICOLON_CHARACTER;
+                    *dest = (char*) SEMICOLON_ASCII_CHARACTER;
                 }
             }
 
@@ -368,7 +370,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) SOLIDUS_CHARACTER;
+                    *dest = (char*) SOLIDUS_ASCII_CHARACTER;
                 }
             }
 
@@ -379,7 +381,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) QUESTION_MARK_CHARACTER;
+                    *dest = (char*) QUESTION_MARK_ASCII_CHARACTER;
                 }
             }
 
@@ -390,7 +392,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) COLON_CHARACTER;
+                    *dest = (char*) COLON_ASCII_CHARACTER;
                 }
             }
 
@@ -401,7 +403,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) COMMERCIAL_AT_CHARACTER;
+                    *dest = (char*) COMMERCIAL_AT_ASCII_CHARACTER;
                 }
             }
 
@@ -412,7 +414,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) EQUALS_SIGN_CHARACTER;
+                    *dest = (char*) EQUALS_SIGN_ASCII_CHARACTER;
                 }
             }
 
@@ -423,7 +425,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) AMPERSAND_CHARACTER;
+                    *dest = (char*) AMPERSAND_ASCII_CHARACTER;
                 }
             }
 
@@ -434,7 +436,7 @@ void* get_character_from_escape_code(void* source, int* source_count, char** des
 
                 if (r == 1) {
 
-                    *dest = (char*) DOLLAR_SIGN_CHARACTER;
+                    *dest = (char*) DOLLAR_SIGN_ASCII_CHARACTER;
                 }
             }
         }
@@ -477,7 +479,7 @@ void get_parameter_from_request_for_post(char* req, int* req_count, char** param
         get_array_elements(req, (void*) &req_index, (void*) &e, (void*) CHARACTER_ARRAY);
 
         // Check of beginning  the paramaters.
-        if ((*e == *LINE_FEED_CONTROL_CHARACTER)) {
+        if ((*e == *LINE_FEED_CONTROL_ASCII_CHARACTER)) {
 
             start_param_index = req_index + 1;
             break;
@@ -543,7 +545,7 @@ void get_parameter_from_request_for_get(char* req, int* req_count, char** param,
         get_array_elements(req, (void*) &req_index, (void*) &e, (void*) CHARACTER_ARRAY);
 
         // Check of ending the paramaters.
-        if ((start_param_flag == 1) && (*e == *SPACE_CHARACTER)) {
+        if ((start_param_flag == 1) && (*e == *SPACE_ASCII_CHARACTER)) {
 
             break;
         }
@@ -560,7 +562,7 @@ void get_parameter_from_request_for_get(char* req, int* req_count, char** param,
         }
 
         // Check of beginning the paramaters.
-        if (*e == *QUESTION_MARK_CHARACTER) {
+        if (*e == *QUESTION_MARK_ASCII_CHARACTER) {
 
             // Begin from the parameters.
             start_param_flag = 1;
@@ -583,7 +585,7 @@ void get_parameter_from_request(char* req, int* req_count, char** param, int* pa
     // Check the request method ( post or get );
     int req_meth_post_res = 0;
 
-    compare_arrays(req, REQEUST_METHOD_POST_COUNT, REQEUST_METHOD_POST, REQEUST_METHOD_POST_COUNT, &req_meth_post_res, CHARACTER_ARRAY);
+    compare_arrays(req, POST_REQUEST_METHOD_COUNT, POST_REQUEST_METHOD, POST_REQUEST_METHOD_COUNT, &req_meth_post_res, CHARACTER_ARRAY);
 
     if (req_meth_post_res == 0) {
 
@@ -650,7 +652,7 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         *sac = 0;
         allocate(&sas, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         *sas = 0;
-        create((void*) &sa, (void*) sac, (void*) sas,
+        receive_file_system_model((void*) &sa, (void*) sac, (void*) sas,
             (void*) OPERATION_ABSTRACTION, (void*) OPERATION_ABSTRACTION_COUNT,
             (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
             (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
@@ -660,7 +662,7 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         *smc = 0;
         allocate(&sms, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         *sms = 0;
-        create((void*) &sm, (void*) smc, (void*) sms,
+        receive_file_system_model((void*) &sm, (void*) smc, (void*) sms,
             (void*) COPY_MODEL, (void*) COPY_MODEL_COUNT,
             (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
             (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
@@ -670,7 +672,7 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         *sdc = 0;
         allocate(&sds, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         *sds = 0;
-        create((void*) &sd, (void*) sdc, (void*) sds,
+        receive_file_system_model((void*) &sd, (void*) sdc, (void*) sds,
             (void*) COMPOUND_ABSTRACTION, (void*) COMPOUND_ABSTRACTION_COUNT,
             (void*) COMPOUND_ABSTRACTION, (void*) COMPOUND_ABSTRACTION_COUNT,
             (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
@@ -705,9 +707,8 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         *pdnc = 0;
         allocate(&pdns, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         *pdns = 0;
-        create((void*) &pdn, (void*) pdnc, (void*) pdns,
-            (void*) DESTINATION_NAME,
-            (void*) DESTINATION_NAME_COUNT,
+        receive_file_system_model((void*) &pdn, (void*) pdnc, (void*) pdns,
+            (void*) COPY_DESTINATION_NAME, (void*) COPY_DESTINATION_NAME_COUNT,
             (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
             (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
 
@@ -716,7 +717,7 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         *pdac = 0;
         allocate(&pdas, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         *pdas = 0;
-        create((void*) &pda, (void*) pdac, (void*) pdas,
+        receive_file_system_model((void*) &pda, (void*) pdac, (void*) pdas,
             (void*) KNOWLEDGE_ABSTRACTION, (void*) KNOWLEDGE_ABSTRACTION_COUNT,
             (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
             (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
@@ -726,7 +727,7 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         *pdmc = 0;
         allocate(&pdms, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         *pdms = 0;
-        create((void*) &pdm, (void*) pdmc, (void*) pdms,
+        receive_file_system_model((void*) &pdm, (void*) pdmc, (void*) pdms,
             (void*) dest, (void*) dest_count,
             (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
             (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
@@ -763,9 +764,8 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         *psnc = 0;
         allocate(&psns, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         *psns = 0;
-        create((void*) &psn, (void*) psnc, (void*) psns,
-            (void*) SOURCE_NAME,
-            (void*) SOURCE_NAME_COUNT,
+        receive_file_system_model((void*) &psn, (void*) psnc, (void*) psns,
+            (void*) COPY_SOURCE_NAME, (void*) COPY_SOURCE_NAME_COUNT,
             (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
             (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
 
@@ -775,7 +775,7 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         *psac = 0;
         allocate(&psas, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         *psas = 0;
-        create((void*) &psa, (void*) psac, (void*) psas,
+        receive_file_system_model((void*) &psa, (void*) psac, (void*) psas,
             (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
             (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
             (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
@@ -786,7 +786,7 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         *psmc = 0;
         allocate(&psms, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         *psms = 0;
-        create((void*) &psm, (void*) psmc, (void*) psms,
+        receive_file_system_model((void*) &psm, (void*) psmc, (void*) psms,
             (void*) source, (void*) source_count,
             (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
             (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
@@ -795,14 +795,14 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         // is empty
 
         // Add property source to the signal detail compound.
-        set_compound_element_by_name( sd, sdc, sds,
+        set_compound_element_by_name(sd, sdc, sds, NULL_POINTER, NULL_POINTER, NULL_POINTER,
             psn, (void*) psnc, (void*) psns,
             psa, (void*) psac, (void*) psas,
             psm, (void*) psmc, (void*) psms,
             psd, (void*) psdc, (void*) psds);
 
         // Add property destination to the detail compound.
-        set_compound_element_by_name( sd, sdc, sds,
+        set_compound_element_by_name(sd, sdc, sds, NULL_POINTER, NULL_POINTER, NULL_POINTER,
             pdn, (void*) pdnc, (void*) pdns,
             pda, (void*) pdac, (void*) pdas,
             pdm, (void*) pdmc, (void*) pdms,
@@ -825,6 +825,9 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         get(p4, (void*) SIGNAL_MEMORY_COUNT_INTERNAL, (void*) &mc, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
         get(p4, (void*) SIGNAL_MEMORY_SIZE_INTERNAL, (void*) &ms, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
 
+        // Lock signal memory mutex.
+//??        pthread_mutex_lock(*mt);
+
         // The signal id.
         int* id = NULL_POINTER;
         allocate(&id, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
@@ -832,11 +835,14 @@ void set_signal_for_parameter(void* source, int* source_count, void* dest, int*
         get_new_signal_id(*m, *mc, (void*) id);
 
         // Set signal.
-        set_signal(*m, *mc, *ms,
-            (void*) sa, (void*) sac,
-            (void*) sm, (void*) smc,
-            (void*) sd, (void*) sdc,
-            (void*) NORMAL_PRIORITY, (void*) id);
+        set_signal(*m, *mc, *ms, (void*) sa, (void*) sac, (void*) sm, (void*) smc, (void*) sd, (void*) sdc, (void*) NORMAL_PRIORITY, (void*) id);
+
+        // Set interrupt request flag, in order to notify the signal checker
+        // that a new signal has been placed in the signal memory.
+//??        **irq = *NUMBER_1_INTEGER;
+
+        // Unlock signal memory mutex.
+//??        pthread_mutex_unlock(*mt);
     }
 }
 
@@ -910,7 +916,7 @@ void set_signals_for_all_parameters(void* p0, int* p1, void* p2) {
 
                 get_array_elements((void*) p0, (void*) &query_counter, (void*) &element, CHARACTER_ARRAY);
 
-                compare_arrays(element, &temp_count, EQUALS_SIGN_CHARACTER, CHARACTER_COUNT, &r, CHARACTER_ARRAY);
+                compare_arrays(element, &temp_count, EQUALS_SIGN_ASCII_CHARACTER, PRIMITIVE_COUNT, &r, CHARACTER_ARRAY);
 
                 if ((query_counter >= *p1) || (r == 1)) {
 
@@ -944,7 +950,7 @@ void set_signals_for_all_parameters(void* p0, int* p1, void* p2) {
 
                 get_array_elements((void*) p0, (void*) &query_counter, (void*) &element, CHARACTER_ARRAY);
 
-                compare_arrays(element, &temp_count, AMPERSAND_CHARACTER, CHARACTER_COUNT, &r, CHARACTER_ARRAY);
+                compare_arrays(element, &temp_count, AMPERSAND_ASCII_CHARACTER, PRIMITIVE_COUNT, &r, CHARACTER_ARRAY);
 
                 if ((query_counter >= *p1) || (r == 1)) {
 
@@ -989,6 +995,11 @@ void set_signals_for_all_parameters(void* p0, int* p1, void* p2) {
  */
 void handle_tcp_socket_request(void* p0, void* p1) {
 
+/*??
+    For web frontend testing, use:
+    http://localhost:3456/resadmin/logic/send_name.cybol
+*/
+
     if (p1 != NULL_POINTER) {
 
         int* cs = (int*) p1;
@@ -1094,13 +1105,13 @@ void handle_tcp_socket_request(void* p0, void* p1) {
                 *dds = 0;
 
                 // Create destination abstraction.
-                create((void*) &da, (void*) dac, (void*) das,
+                receive_file_system_model((void*) &da, (void*) dac, (void*) das,
                     (void*) sa, (void*) sac,
                     (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
                     (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
 
                 // Create destination model.
-                create((void*) &dm, (void*) dmc, (void*) dms,
+                receive_file_system_model((void*) &dm, (void*) dmc, (void*) dms,
                     (void*) sm, (void*) smc,
                     (void*) sa, (void*) sac,
                     (void*) sc, (void*) scc);
@@ -1121,6 +1132,9 @@ void handle_tcp_socket_request(void* p0, void* p1) {
                 get(p0, (void*) SIGNAL_MEMORY_COUNT_INTERNAL, (void*) &mc, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
                 get(p0, (void*) SIGNAL_MEMORY_SIZE_INTERNAL, (void*) &ms, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
 
+                // Lock signal memory mutex.
+//??                pthread_mutex_lock(*mt);
+
                 // The signal id.
                 int* id = NULL_POINTER;
                 allocate(&id, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
@@ -1137,6 +1151,13 @@ void handle_tcp_socket_request(void* p0, void* p1) {
                 add_signal_id(p0, (void*) id);
                 add_client_socket_number(p0, (void*) cs);
 
+                // Set interrupt request flag, in order to notify the signal checker
+                // that a new signal has been placed in the signal memory.
+//??                **irq = *NUMBER_1_INTEGER;
+
+                // Unlock signal memory mutex.
+//??                pthread_mutex_unlock(*mt);
+
             } else {
 
                 close(*cs);
@@ -1164,7 +1185,7 @@ void run_tcp_socket(void* p0) {
     void** s = &NULL_POINTER;
 
     // Get tcp server socket.
-    get(p0, (void*) TCP_SERVER_SOCKET_INTERNAL, (void*) &s, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+    get(p0, (void*) TCP_SOCKET_INTERNAL, (void*) &s, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
 
     if (s != NULL_POINTER) {
 
@@ -1192,7 +1213,7 @@ void run_tcp_socket(void* p0) {
                 pthread_exit(NULL_POINTER);
             }
 
-        }else {
+        } else {
 
             log_message_debug("Could not run tcp socket. The socket is null.");
         }
@@ -1213,13 +1234,14 @@ void run_tcp_socket(void* p0) {
  */
 void run_tcp_socket_server(void* p0) {
 
-    int** active_flag = (int**) &NULL_POINTER;
+    // The interrupt flag.
+    int** f = (int**) &NULL_POINTER;
 
-    get(p0, (void*) TCP_SERVER_SOCKET_ACTIVE_INTERNAL, (void*) &active_flag, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+//??    get(p0, (void*) TCP_SOCKET_INTERRUPT_INTERNAL, (void*) &f, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
 
     while (1) {
 
-        if (**active_flag == *NUMBER_0_INTEGER) {
+        if (**f == *NUMBER_1_INTEGER) {
 
             break;
         }
@@ -1276,33 +1298,41 @@ void receive_tcp_socket(void* p0, void* p1, void* p2, void* p3,
 */
                 }
 
-                // Set the activation flag in the internal memory.
-                int** socket_flag = (int**) &NULL_POINTER;
+                // The interrupt flag.
+                int** f = (int**) &NULL_POINTER;
 
-                get(p0, (void*) TCP_SERVER_SOCKET_ACTIVE_INTERNAL, (void*) &socket_flag, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+//??                get(p0, (void*) TCP_SOCKET_INTERRUPT_INTERNAL, (void*) &f, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
 
-                if ((socket_flag != NULL_POINTER) && (*socket_flag != NULL_POINTER)) {
+                if ((f != NULL_POINTER) && (*f != NULL_POINTER)) {
 
-                    **socket_flag = 1;
+                    // Deactivate interrupt flag, since tcp socket service is now running.
+                    **f = 0;
                 }
 
-                //set the blocking flag in the internal memory.
-                int** blocking_flag = (int**) &NULL_POINTER;
+                // The blocking flag.
+                int** b = (int**) &NULL_POINTER;
 
-                get(p0, (void*) TCP_SERVER_SOCKET_BLOCKING_INTERNAL, (void*) &blocking_flag, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+                get(p0, (void*) TCP_SOCKET_BLOCKING_INTERNAL, (void*) &b, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
 
-                if ((blocking_flag != NULL_POINTER) && (*blocking_flag != NULL_POINTER)) {
+                if ((b != NULL_POINTER) && (*b != NULL_POINTER)) {
 
-                    **blocking_flag = *((int*) blocking_model);
+                    **b = *((int*) blocking_model);
                 }
             }
+
+        } else {
+
+            log_message_debug("Could not receive via tcp socket. The blocking flag is null.");
         }
 
     } else {
 
-        log_message_debug("Could not receive tcp socket. The internal memory is null.");
+        log_message_debug("Could not receive via tcp socket. The internal memory is null.");
     }
 }
 
+/* LINUX_OPERATING_SYSTEM */
+#endif
+
 /* RECEIVE_TCP_SOCKET_SOURCE */
 #endif
