@@ -1,7 +1,7 @@
 /*
  * $RCSfile: cyboi.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,7 +25,7 @@
  * CYBOI can interpret Cybernetics Oriented Language (CYBOL) files,
  * which adhere to the Extended Markup Language (XML) syntax.
  *
- * @version $Revision: 1.11 $ $Date: 2005/08/31 14:50:18 $ $Author: christian $
+ * @version $Revision: 1.17 $ $Date: 2006/06/25 22:08:25 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -68,13 +68,13 @@ int main(int p0, char** p1) {
     // Call testing procedures. Comment/ uncomment this as needed!
     // CAUTION! This has to stand AFTER the initialization of the
     // global variables because these are used by the testing code.
-//??    test(); deallocate_globals(); r = 0; return r;
+//??    test(); r = 0; shutdown_globals(); return r;
 
     if (p1 != NULL_POINTER) {
 
         if (p0 == *STARTUP_PARAMETERS_COUNT) {
 
-            log_message_debug("Execute CYBOI.");
+            log_message_debug("Info: Execute CYBOI.");
 
             // The run source name.
             void** s = &NULL_POINTER;
@@ -104,7 +104,7 @@ int main(int p0, char** p1) {
 
             } else {
 
-                log_message_debug("Could not execute CYBOI. The run source name is null.");
+                log_message_debug("Error: Could not execute CYBOI. The run source name is null.");
             }
 
         } else {
