@@ -1,7 +1,7 @@
 /*
  * $RCSfile: key_code_constants.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.2 $ $Date: 2005/08/21 19:14:46 $ $Author: christian $
+ * @version $Revision: 1.4 $ $Date: 2006/04/20 22:36:10 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -408,10 +408,10 @@ static int NUMERIC_LEFT_KEY_CODE_ARRAY[] = {75};
 static int* NUMERIC_LEFT_KEY_CODE = NUMERIC_LEFT_KEY_CODE_ARRAY;
 static int* NUMERIC_LEFT_KEY_CODE_COUNT = NUMBER_1_INTEGER_ARRAY;
 
-/** The numeric center (five) key code. */
-static int NUMERIC_CENTER_KEY_CODE_ARRAY[] = {76};
-static int* NUMERIC_CENTER_KEY_CODE = NUMERIC_CENTER_KEY_CODE_ARRAY;
-static int* NUMERIC_CENTER_KEY_CODE_COUNT = NUMBER_1_INTEGER_ARRAY;
+/** The numeric centre (five) key code. */
+static int NUMERIC_CENTRE_KEY_CODE_ARRAY[] = {76};
+static int* NUMERIC_CENTRE_KEY_CODE = NUMERIC_CENTRE_KEY_CODE_ARRAY;
+static int* NUMERIC_CENTRE_KEY_CODE_COUNT = NUMBER_1_INTEGER_ARRAY;
 
 /** The numeric right (six) key code. */
 static int NUMERIC_RIGHT_KEY_CODE_ARRAY[] = {77};
