@@ -1,7 +1,7 @@
 /*
  * $RCSfile: structure_constants.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.16 $ $Date: 2005/08/09 13:04:26 $ $Author: christian $
+ * @version $Revision: 1.25 $ $Date: 2006/08/19 02:04:48 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @author Rolf Holzmueller <rolf.holzmueller@gmx.de>
  */
@@ -114,83 +114,30 @@ static int* COMPLEX_REAL_INDEX = NUMBER_0_INTEGER_ARRAY;
 static int* COMPLEX_IMAGINARY_INDEX = NUMBER_1_INTEGER_ARRAY;
 
 //
-// Textual user interface (tui).
+// User interface (ui) position.
 //
 
-/** The tui reallocate factor. */
-static int* TUI_REALLOCATE_FACTOR = NUMBER_2_INTEGER_ARRAY;
+/** The ui position x index. */
+static int* UI_POSITION_X_INDEX = NUMBER_0_INTEGER_ARRAY;
 
-/** The tui count. */
-static int* TUI_COUNT = NUMBER_4_INTEGER_ARRAY;
+/** The ui position y index. */
+static int* UI_POSITION_Y_INDEX = NUMBER_1_INTEGER_ARRAY;
 
-/** The tui z dimension index. */
-static int* TUI_Z_DIMENSION_INDEX = NUMBER_0_INTEGER_ARRAY;
-
-/** The tui y dimension index. */
-static int* TUI_Y_DIMENSION_INDEX = NUMBER_1_INTEGER_ARRAY;
-
-/** The tui x dimension index. */
-static int* TUI_X_DIMENSION_INDEX = NUMBER_2_INTEGER_ARRAY;
-
-/** The tui properties index. */
-static int* TUI_PROPERTIES_INDEX = NUMBER_3_INTEGER_ARRAY;
+/** The ui position z index. */
+static int* UI_POSITION_Z_INDEX = NUMBER_2_INTEGER_ARRAY;
 
 //
-// Textual user interface (tui) properties.
+// User interface (ui) size.
 //
 
-/** The tui properties count. */
-static int* TUI_PROPERTIES_COUNT = NUMBER_8_INTEGER_ARRAY;
+/** The ui size x index. */
+static int* UI_SIZE_X_INDEX = NUMBER_0_INTEGER_ARRAY;
 
-/** The tui properties character index. */
-static int* TUI_PROPERTIES_CHARACTER_INDEX = NUMBER_0_INTEGER_ARRAY;
+/** The ui size y index. */
+static int* UI_SIZE_Y_INDEX = NUMBER_1_INTEGER_ARRAY;
 
-/** The tui properties bold index. */
-static int* TUI_PROPERTIES_BOLD_INDEX = NUMBER_1_INTEGER_ARRAY;
-
-/** The tui properties underline index. */
-static int* TUI_PROPERTIES_UNDERLINE_INDEX = NUMBER_2_INTEGER_ARRAY;
-
-/** The tui properties blink index. */
-static int* TUI_PROPERTIES_BLINK_INDEX = NUMBER_3_INTEGER_ARRAY;
-
-/** The tui properties inverse index. */
-static int* TUI_PROPERTIES_INVERSE_INDEX = NUMBER_4_INTEGER_ARRAY;
-
-/** The tui properties hidden index. */
-static int* TUI_PROPERTIES_HIDDEN_INDEX = NUMBER_5_INTEGER_ARRAY;
-
-/** The tui properties foreground index. */
-static int* TUI_PROPERTIES_FOREGROUND_INDEX = NUMBER_6_INTEGER_ARRAY;
-
-/** The tui properties background index. */
-static int* TUI_PROPERTIES_BACKGROUND_INDEX = NUMBER_7_INTEGER_ARRAY;
-
-//
-// Textual user interface (tui) position.
-//
-
-/** The tui position x index. */
-static int* TUI_POSITION_X_INDEX = NUMBER_0_INTEGER_ARRAY;
-
-/** The tui position y index. */
-static int* TUI_POSITION_Y_INDEX = NUMBER_1_INTEGER_ARRAY;
-
-/** The tui position z index. */
-static int* TUI_POSITION_Z_INDEX = NUMBER_2_INTEGER_ARRAY;
-
-//
-// Textual user interface (tui) size.
-//
-
-/** The tui size x index. */
-static int* TUI_SIZE_X_INDEX = NUMBER_0_INTEGER_ARRAY;
-
-/** The tui size y index. */
-static int* TUI_SIZE_Y_INDEX = NUMBER_1_INTEGER_ARRAY;
-
-/** The tui size z index. */
-static int* TUI_SIZE_Z_INDEX = NUMBER_2_INTEGER_ARRAY;
+/** The ui size z index. */
+static int* UI_SIZE_Z_INDEX = NUMBER_2_INTEGER_ARRAY;
 
 //
 // Compound.
@@ -277,7 +224,7 @@ static int* SIGNALS_IDENTIFICATIONS_INDEX = NUMBER_7_INTEGER_ARRAY;
 //
 
 /** The internal memory elements count. */
-static int* INTERNAL_MEMORY_ELEMENTS_COUNT = NUMBER_41_INTEGER_ARRAY;
+static int* INTERNAL_MEMORY_ELEMENTS_COUNT = NUMBER_400_INTEGER_ARRAY;
 
 /** The knowledge memory. */
 static int* KNOWLEDGE_MEMORY_INTERNAL = NUMBER_0_INTEGER_ARRAY;
@@ -288,55 +235,74 @@ static int* KNOWLEDGE_MEMORY_SIZE_INTERNAL = NUMBER_2_INTEGER_ARRAY;
 static int* SIGNAL_MEMORY_INTERNAL = NUMBER_3_INTEGER_ARRAY;
 static int* SIGNAL_MEMORY_COUNT_INTERNAL = NUMBER_4_INTEGER_ARRAY;
 static int* SIGNAL_MEMORY_SIZE_INTERNAL = NUMBER_5_INTEGER_ARRAY;
+static int* SIGNAL_MEMORY_MUTEX_INTERNAL = NUMBER_6_INTEGER_ARRAY;
 
-/** The unix server socket. */
-static int* UNIX_SERVER_SOCKET_ACTIVE_INTERNAL = NUMBER_6_INTEGER_ARRAY;
-static int* UNIX_SERVER_SOCKET_INTERNAL = NUMBER_7_INTEGER_ARRAY;
-static int* UNIX_SERVER_SOCKET_FILENAME_INTERNAL = NUMBER_8_INTEGER_ARRAY;
-
-/** The tcp server socket. */
-static int* TCP_SERVER_SOCKET_ACTIVE_INTERNAL = NUMBER_9_INTEGER_ARRAY;
-static int* TCP_SERVER_SOCKET_INTERNAL = NUMBER_10_INTEGER_ARRAY;
-static int* TCP_SERVER_SOCKET_BLOCKING_INTERNAL = NUMBER_11_INTEGER_ARRAY;
-
-/** The tcp client sockets. */
-static int* TCP_CLIENT_SOCKETS_INTERNAL = NUMBER_12_INTEGER_ARRAY;
-static int* TCP_CLIENT_SOCKETS_COUNT_INTERNAL = NUMBER_13_INTEGER_ARRAY;
-static int* TCP_CLIENT_SOCKETS_SIZE_INTERNAL = NUMBER_14_INTEGER_ARRAY;
-
-/** The signal identifications. */
-static int* TCP_CLIENT_SOCKET_SIGNAL_IDS_INTERNAL = NUMBER_15_INTEGER_ARRAY;
-static int* TCP_CLIENT_SOCKET_SIGNAL_IDS_COUNT_INTERNAL = NUMBER_16_INTEGER_ARRAY;
-static int* TCP_CLIENT_SOCKET_SIGNAL_IDS_SIZE_INTERNAL = NUMBER_17_INTEGER_ARRAY;
-
-/** The x window system. */
-static int* X_WINDOW_SYSTEM_DISPLAY_NAME_INTERNAL = NUMBER_18_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_DISPLAY_INTERNAL = NUMBER_19_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_SCREEN_INTERNAL = NUMBER_20_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_SCREEN_NUMBER_INTERNAL = NUMBER_21_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_BACKGROUND_INTERNAL = NUMBER_22_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_FOREGROUND_INTERNAL = NUMBER_23_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_ROOT_WINDOW_INTERNAL = NUMBER_24_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_COLOUR_MAP_INTERNAL = NUMBER_25_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_VALUE_MASK_INTERNAL = NUMBER_26_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_VALUES_INTERNAL = NUMBER_27_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_INTERNAL = NUMBER_28_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_MENU_INTERNAL = NUMBER_29_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_MENU_BORDER_TOP_INTERNAL = NUMBER_30_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_MENU_BORDER_BOTTOM_INTERNAL = NUMBER_31_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_MENU_FONT_INTERNAL = NUMBER_32_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_FONT_NAME_INTERNAL = NUMBER_33_INTEGER_ARRAY;
-static int* X_WINDOW_SYSTEM_FONT_INTERNAL = NUMBER_34_INTEGER_ARRAY;
+/** The interrupt request flag. */
+static int* INTERRUPT_REQUEST_INTERNAL = NUMBER_10_INTEGER_ARRAY;
 
 /** The linux console. */
-static int* TERMINAL_FILE_DESCRIPTOR_INTERNAL = NUMBER_35_INTEGER_ARRAY;
-static int* TERMINAL_ORIGINAL_ATTRIBUTES_INTERNAL = NUMBER_36_INTEGER_ARRAY;
-static int* TERMINAL_WORKING_ATTRIBUTES_INTERNAL = NUMBER_37_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_FILE_DESCRIPTOR_INTERNAL = NUMBER_100_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_ORIGINAL_ATTRIBUTES_INTERNAL = NUMBER_101_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_WORKING_ATTRIBUTES_INTERNAL = NUMBER_102_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_MUTEX_INTERNAL = NUMBER_103_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_INTERNAL = NUMBER_110_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_COUNT_INTERNAL = NUMBER_111_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_SIZE_INTERNAL = NUMBER_112_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_THREAD_ROOT_INTERNAL = NUMBER_190_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_THREAD_ROOT_COUNT_INTERNAL = NUMBER_191_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_THREAD_ROOT_SIZE_INTERNAL = NUMBER_192_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_THREAD_COMMANDS_INTERNAL = NUMBER_193_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_THREAD_COMMANDS_COUNT_INTERNAL = NUMBER_194_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_THREAD_COMMANDS_SIZE_INTERNAL = NUMBER_195_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_THREAD_CHARACTER_BUFFER_INTERNAL = NUMBER_196_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_THREAD_CHARACTER_BUFFER_COUNT_INTERNAL = NUMBER_197_INTEGER_ARRAY;
+static int* LINUX_CONSOLE_THREAD_CHARACTER_BUFFER_SIZE_INTERNAL = NUMBER_198_INTEGER_ARRAY;
 
-/** The textual user interface (tui). */
-static int* TUI_INTERNAL = NUMBER_38_INTEGER_ARRAY;
-static int* TUI_COUNT_INTERNAL = NUMBER_39_INTEGER_ARRAY;
-static int* TUI_SIZE_INTERNAL = NUMBER_40_INTEGER_ARRAY;
+/** The unix socket. */
+static int* UNIX_SOCKET_INTERNAL = NUMBER_200_INTEGER_ARRAY;
+static int* UNIX_SOCKET_FILENAME_INTERNAL = NUMBER_201_INTEGER_ARRAY;
+static int* UNIX_SOCKET_MUTEX_INTERNAL = NUMBER_202_INTEGER_ARRAY;
+
+/** The tcp socket. */
+static int* TCP_SOCKET_INTERNAL = NUMBER_210_INTEGER_ARRAY;
+static int* TCP_SOCKET_BLOCKING_INTERNAL = NUMBER_211_INTEGER_ARRAY;
+static int* TCP_SOCKET_MUTEX_INTERNAL = NUMBER_212_INTEGER_ARRAY;
+
+/** The tcp client sockets. */
+static int* TCP_CLIENT_SOCKETS_INTERNAL = NUMBER_220_INTEGER_ARRAY;
+static int* TCP_CLIENT_SOCKETS_COUNT_INTERNAL = NUMBER_221_INTEGER_ARRAY;
+static int* TCP_CLIENT_SOCKETS_SIZE_INTERNAL = NUMBER_222_INTEGER_ARRAY;
+
+/** The signal identifications. */
+static int* TCP_CLIENT_SOCKET_SIGNAL_IDS_INTERNAL = NUMBER_230_INTEGER_ARRAY;
+static int* TCP_CLIENT_SOCKET_SIGNAL_IDS_COUNT_INTERNAL = NUMBER_231_INTEGER_ARRAY;
+static int* TCP_CLIENT_SOCKET_SIGNAL_IDS_SIZE_INTERNAL = NUMBER_232_INTEGER_ARRAY;
+
+/** The x window system. */
+static int* X_WINDOW_SYSTEM_DISPLAY_NAME_INTERNAL = NUMBER_300_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_DISPLAY_INTERNAL = NUMBER_301_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_SCREEN_INTERNAL = NUMBER_302_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_SCREEN_NUMBER_INTERNAL = NUMBER_303_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_MUTEX_INTERNAL = NUMBER_304_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_ROOT_WINDOW_INTERNAL = NUMBER_310_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_WINDOW_INTERNAL = NUMBER_311_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_COLOUR_MAP_INTERNAL = NUMBER_320_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_BACKGROUND_INTERNAL = NUMBER_321_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_FOREGROUND_INTERNAL = NUMBER_322_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_VALUE_MASK_INTERNAL = NUMBER_330_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_VALUES_INTERNAL = NUMBER_331_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_INTERNAL = NUMBER_332_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_MENU_INTERNAL = NUMBER_333_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_MENU_BORDER_TOP_INTERNAL = NUMBER_334_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_MENU_BORDER_BOTTOM_INTERNAL = NUMBER_335_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_GRAPHIC_CONTEXT_MENU_FONT_INTERNAL = NUMBER_336_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_WINDOW_MENU_BORDER_BOTTOM_GC_INTERNAL = NUMBER_337_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_THREAD_ROOT_INTERNAL = NUMBER_390_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_THREAD_ROOT_COUNT_INTERNAL = NUMBER_391_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_THREAD_ROOT_SIZE_INTERNAL = NUMBER_392_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_THREAD_COMMANDS_INTERNAL = NUMBER_393_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_THREAD_COMMANDS_COUNT_INTERNAL = NUMBER_394_INTEGER_ARRAY;
+static int* X_WINDOW_SYSTEM_THREAD_COMMANDS_SIZE_INTERNAL = NUMBER_395_INTEGER_ARRAY;
 
 //
 // Xml tag.
