@@ -1,7 +1,7 @@
 /*
  * $RCSfile: logger.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,7 +27,7 @@
  * Otherwise, an ENDLESS LOOP will be created, because cyboi's
  * array procedures call the logger in turn.
  *
- * @version $Revision: 1.9 $ $Date: 2005/08/31 14:50:18 $ $Author: christian $
+ * @version $Revision: 1.12 $ $Date: 2006/04/20 22:36:10 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @author Rolf Holzmueller <rolf.holzmueller@gmx.de>
  */
@@ -35,10 +35,11 @@
 #ifndef LOGGER_SOURCE
 #define LOGGER_SOURCE
 
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include "../../globals/constants/character_constants.c"
+#include "../../globals/constants/ascii_character_constants.c"
 #include "../../globals/constants/log_constants.c"
 #include "../../globals/constants/structure_constants.c"
 #include "../../globals/variables/variables.c"
@@ -256,11 +257,11 @@ void log_message(void* p0, void* p1, void* p2) {
                 e = (void*) realloc(e, ec);
 
                 // Add colon to log entry.
-                add_log_details((void*) &e, (void*) &ei, (void*) COLON_CHARACTER, (void*) CHARACTER_COUNT);
+                add_log_details((void*) &e, (void*) &ei, (void*) COLON_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT);
                 ei = ei + 1;
 
                 // Add space to log entry.
-                add_log_details((void*) &e, (void*) &ei, (void*) SPACE_CHARACTER, (void*) CHARACTER_COUNT);
+                add_log_details((void*) &e, (void*) &ei, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT);
                 ei = ei + 1;
 
                 // Add message to log entry.
@@ -268,7 +269,7 @@ void log_message(void* p0, void* p1, void* p2) {
                 ei = ei + *mc;
 
                 // Add new line to log entry.
-                add_log_details((void*) &e, (void*) &ei, (void*) LINE_FEED_CONTROL_CHARACTER, (void*) CHARACTER_COUNT);
+                add_log_details((void*) &e, (void*) &ei, (void*) LINE_FEED_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT);
                 ei = ei + 1;
 
                 // Log entry to output.
