@@ -1,7 +1,7 @@
 /*
  * $RCSfile: html_translator.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.13 $ $Date: 2005/08/11 22:33:47 $ $Author: christian $
+ * @version $Revision: 1.22 $ $Date: 2006/06/20 16:16:29 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -29,8 +29,7 @@
 
 #include "../../globals/constants/abstraction_constants.c"
 #include "../../globals/constants/channel_constants.c"
-#include "../../globals/constants/character_constants.c"
-#include "../../globals/constants/constant.c"
+#include "../../globals/constants/ascii_character_constants.c"
 #include "../../globals/constants/log_constants.c"
 #include "../../globals/constants/name_constants.c"
 #include "../../globals/constants/structure_constants.c"
@@ -139,12 +138,13 @@ void encode_html_knowledgememory(void** dest, int* dest_count, int* dest_size,
         void** comp_detail_count = &NULL_POINTER;
         void** comp_detail_size = &NULL_POINTER;
 
-        get_compound_element_by_name(
+        get_universal_compound_element_by_name(
             know, know_count,
             source_model, source_model_count,
             &comp_abstr, &comp_abstr_count, &comp_abstr_size,
             &comp_model, &comp_model_count, &comp_model_size,
-            &comp_detail, &comp_detail_count, &comp_detail_size );
+            &comp_detail, &comp_detail_count, &comp_detail_size,
+            know, know_count);
 
         encode_html( dest, dest_count, dest_size,
                      *comp_abstr, *comp_abstr_count,
@@ -170,35 +170,27 @@ void encode_html_knowledgememory(void** dest, int* dest_count, int* dest_size,
  * @param source_detail the source detail
  * @param source_detail_count the source detail count
  */
-void encode_html_string( void** dest, int* dest_count, int* dest_size,
-                         void* source_model, int* source_model_count,
-                         void* source_detail, int* source_detail_count)
-{
+void encode_html_string(void** dest, int* dest_count, int* dest_size,
+    void* source_model, int* source_model_count, void* source_detail, int* source_detail_count) {
 
-    if ( (dest != NULL_POINTER ) &&
-         (dest_count != NULL_POINTER ) &&
-         (dest_size != NULL_POINTER ) )
-    {
+    if ((dest != NULL_POINTER)
+        && (dest_count != NULL_POINTER)
+        && (dest_size != NULL_POINTER)) {
 
-        //parse the model
-        parse( dest, dest_count, dest_size,
-               source_model, source_model_count,
-               CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
+        // Parse the model.
+        parse(dest, dest_count, dest_size, source_model, source_model_count,
+            CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
     }
 }
 
+void encode_html_integer(void** dest, int* dest_count, int* dest_size,
+    void* source_model, int* source_model_count, void* source_detail, int* source_detail_count) {
 
-void encode_html_integer( void** dest, int* dest_count, int* dest_size,
-                         void* source_model, int* source_model_count,
-                         void* source_detail, int* source_detail_count)
-{
+    if ((dest != NULL_POINTER)
+        && (dest_count != NULL_POINTER)
+        && (dest_size != NULL_POINTER)) {
 
-    if ( (dest != NULL_POINTER ) &&
-         (dest_count != NULL_POINTER ) &&
-         (dest_size != NULL_POINTER ) )
-    {
-
-        //parse the model
+        // Parse the model.
         void* dest_int = NULL_POINTER;
         int* dest_int_count = NULL_POINTER;
         int* dest_int_size = NULL_POINTER;
@@ -207,20 +199,24 @@ void encode_html_integer( void** dest, int* dest_count, int* dest_size,
         *dest_int_count = 0;
         allocate(&dest_int_size, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         *dest_int_size = 0;
+
+/*??
+    //?? REACTIVATE THIS LATER! It was commented out because of the missing
+    //?? knowledge memory parameters to be handed over to the "serialise" procedure.
         create((void*) &dest_int, (void*) dest_int_count, (void*) dest_int_size,
-            (void*) SPACE_CHARACTER , (void*) CHARACTER_COUNT,
+            (void*) SPACE_ASCII_CHARACTER , (void*) PRIMITIVE_COUNT,
             (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
             (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
 
         serialise( &dest_int, dest_int_count, dest_int_size,
                source_model, source_model_count,
                INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
+*/
 
         //parse the model
         parse( dest, dest_count, dest_size,
                dest_int, dest_int_count,
                CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
-
     }
 }
 
@@ -282,16 +278,16 @@ void encode_html(void** dest, int* dest_count, int *dest_size,
         if ( (source_detail != NULL_POINTER) &&
              (source_detail_count != NULL_POINTER) ) {
 
-            get_compound_element_by_name(
-                source_detail, source_detail_count,
+            get_compound_element_by_name(source_detail, source_detail_count,
+                NULL_POINTER, NULL_POINTER,
                 WUI_TAG_NAME, WUI_TAG_NAME_COUNT,
                 &tag_abstr, &tag_abstr_count, &tag_abstr_size,
                 &tag_model, &tag_model_count, &tag_model_size,
                 &tag_detail, &tag_detail_count, &tag_detail_size
             );
 
-            get_compound_element_by_name(
-                source_detail, source_detail_count,
+            get_compound_element_by_name(source_detail, source_detail_count,
+                NULL_POINTER, NULL_POINTER,
                 WUI_PROPERTY_NAME,
                 WUI_PROPERTY_NAME_COUNT,
                 &tag_prop_abstr, &tag_prop_abstr_count, &tag_prop_abstr_size,
@@ -312,7 +308,7 @@ void encode_html(void** dest, int* dest_count, int *dest_size,
 
                 // Parse the <
                 parse(dest, dest_count, dest_size,
-                    LESS_THAN_SIGN_CHARACTER, CHARACTER_COUNT,
+                    LESS_THAN_SIGN_ASCII_CHARACTER, PRIMITIVE_COUNT,
                     CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
 
                 //parse the html tag
@@ -327,7 +323,7 @@ void encode_html(void** dest, int* dest_count, int *dest_size,
 
                     // Parse the space.
                     parse(dest, dest_count, dest_size,
-                        SPACE_CHARACTER, CHARACTER_COUNT,
+                        SPACE_ASCII_CHARACTER, PRIMITIVE_COUNT,
                         CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
 
                     // Parse the html tag properties.
@@ -338,12 +334,12 @@ void encode_html(void** dest, int* dest_count, int *dest_size,
 
                 //parse the >
                 parse( dest, dest_count, dest_size,
-                       GREATER_THAN_SIGN_CHARACTER, CHARACTER_COUNT,
+                       GREATER_THAN_SIGN_ASCII_CHARACTER, PRIMITIVE_COUNT,
                        CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
 
                 //parse the line feed for better reading the html-source
                 parse( dest, dest_count, dest_size,
-                       LINE_FEED_CONTROL_CHARACTER, CHARACTER_COUNT,
+                       LINE_FEED_CONTROL_ASCII_CHARACTER, PRIMITIVE_COUNT,
                        CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
             }
         }
@@ -381,7 +377,7 @@ void encode_html(void** dest, int* dest_count, int *dest_size,
 
         if (r != 1) {
 
-            compare_arrays(source_abstr, source_abstr_count, (void*) CYBOL_ABSTRACTION, (void*) CYBOL_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+            compare_arrays(source_abstr, source_abstr_count, (void*) COMPOUND_ABSTRACTION, (void*) COMPOUND_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
             if (r == 1) {
 
@@ -423,7 +419,7 @@ void encode_html(void** dest, int* dest_count, int *dest_size,
 
         //parse the line feed for better reading the html-source
         parse( dest, dest_count, dest_size,
-               LINE_FEED_CONTROL_CHARACTER, CHARACTER_COUNT,
+               LINE_FEED_CONTROL_ASCII_CHARACTER, PRIMITIVE_COUNT,
                CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
 
         //parse the end tag
@@ -437,12 +433,12 @@ void encode_html(void** dest, int* dest_count, int *dest_size,
 
                 //parse the <
                 parse( dest, dest_count, dest_size,
-                       LESS_THAN_SIGN_CHARACTER, CHARACTER_COUNT,
+                       LESS_THAN_SIGN_ASCII_CHARACTER, PRIMITIVE_COUNT,
                        CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
 
                 //parse the /
                 parse( dest, dest_count, dest_size,
-                       SOLIDUS_CHARACTER, CHARACTER_COUNT,
+                       SOLIDUS_ASCII_CHARACTER, PRIMITIVE_COUNT,
                        CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
 
                 //parse the html tag
@@ -452,12 +448,12 @@ void encode_html(void** dest, int* dest_count, int *dest_size,
 
                 //parse the >
                 parse( dest, dest_count, dest_size,
-                       GREATER_THAN_SIGN_CHARACTER, CHARACTER_COUNT,
+                       GREATER_THAN_SIGN_ASCII_CHARACTER, PRIMITIVE_COUNT,
                        CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
 
                 //parse the line feed for better reading the html-source
                 parse( dest, dest_count, dest_size,
-                       LINE_FEED_CONTROL_CHARACTER, CHARACTER_COUNT,
+                       LINE_FEED_CONTROL_ASCII_CHARACTER, PRIMITIVE_COUNT,
                        CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
             }
         }
