@@ -1,7 +1,7 @@
 /*
  * $RCSfile: tester.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,7 +24,7 @@
  *
  * From here all tests can be activated or deactivated.
  *
- * @version $Revision: 1.15 $ $Date: 2005/08/11 22:33:47 $ $Author: christian $
+ * @version $Revision: 1.27 $ $Date: 2006/06/25 22:08:25 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @author Rolf Holzmueller <rolf.holzmueller@gmx.de>
  */
@@ -32,7 +32,21 @@
 #ifndef TEST_SOURCE
 #define TEST_SOURCE
 
+#ifdef LINUX_OPERATING_SYSTEM
+#include <termios.h>
+/* LINUX_OPERATING_SYSTEM */
+#endif
+
+#ifdef CYGWIN_ENVIRONMENT
+#include <windows.h>
+/* CYGWIN_ENVIRONMENT */
+#endif
+
+#include <locale.h>
 #include <stdio.h>
+#include <wchar.h>
+#include "../globals/constants/abstraction_constants.c"
+#include "../globals/constants/character_constants.c"
 #include "../globals/constants/structure_constants.c"
 #include "../globals/variables/variables.c"
 #include "../memoriser/accessor/compound_accessor.c"
@@ -40,6 +54,59 @@
 #include "../memoriser/array.c"
 #include "../memoriser/converter.c"
 
+/**
+ * Tests the inline assembler code.
+ */
+void test_inline_assembler_code() {
+
+    fputs("Test inline assembler code:\n", stdout);
+
+    // Gegeben ist ein zusammenhngender Block von Worten im RAM.
+    // Die Startadresse des Blockes ist im Register ESI angegeben,
+    // die Anzahl der Werte im Register ECX.
+    // Schreiben Sie ein Programmstck, welches die Anzahl der Worte
+    // in diesem Block zhlt, deren Wert gleich dem ist, welcher im
+    // Register DI vorgegeben ist.
+    // Das Ergebnis soll nach Abarbeitung des Programms im Register EAX stehen.
+    //
+    // - block of words in RAM
+    // - ESI = start address
+    // - ECX = number of values
+    // - count number of words in RAM block with value == DI
+    // - write result to EAX
+
+/*??
+            MOV EAX, 0; initial word count
+            MOV EDX, 0; loop count
+    loop:   CMP ECX, 0
+            JZ end
+            DEC ECX
+            MOV EBX, [ESI + EDX * 2]
+            CMP EBX, DI
+            JNZ loop
+            INC EAX
+            JMP loop
+    end:    NOP
+*/
+}
+
+/**
+ * Tests the preprocessor directives.
+ */
+void test_preprocessor_directives() {
+
+    fputs("Test preprocessor directives:\n", stdout);
+
+#ifdef LINUX_OPERATING_SYSTEM
+    fputs("LINUX\n", stdout);
+#elif WINDOWS_OPERATING_SYSTEM
+    fputs("WINDOWS\n", stdout);
+#else
+    fputs("OTHER\n", stdout);
+/* LINUX_OPERATING_SYSTEM */
+#endif
+}
+
 /**
  * Tests the standard output and error stream.
  */
@@ -70,6 +137,237 @@ void test_character_array_with_termination() {
     fputs(test, stdout);
 }
 
+/**
+ * Tests the character array with termination.
+ */
+void test_array_resizing() {
+
+    fputs("Test array resizing:\n", stdout);
+
+    // The text.
+    char ta[] = {'t', 'e', 's', 't', '\n', '\0'};
+    char* t = ta;
+    int* tc = NUMBER_6_INTEGER_ARRAY;
+
+    // The original array.
+    void* o = NULL_POINTER;
+    int oc = 0;
+    int os = *tc;
+    // The copied array.
+    void* c = NULL_POINTER;
+    int cc = 0;
+    int cs = 0;
+
+    // Allocate original array.
+    allocate_array((void*) &o, (void*) &os, (void*) CHARACTER_ARRAY);
+    // Allocate copied array.
+    allocate_array((void*) &c, (void*) &cs, (void*) CHARACTER_ARRAY);
+
+    // Fill original array with text.
+    set_array_elements(o, (void*) &oc, (void*) t, (void*) tc, (void*) CHARACTER_ARRAY);
+    oc = oc + *tc;
+
+    // Print original array content.
+    fputs(t, stdout);
+
+    // Reallocate copied array.
+    os = os + 10;
+    reallocate_array((void*) &o, (void*) &oc, (void*) &os, (void*) CHARACTER_ARRAY);
+
+    // Print original array content.
+    fputs(t, stdout);
+
+    // Deallocate original array.
+    deallocate_array((void*) &o, (void*) &os, (void*) CHARACTER_ARRAY);
+    // Deallocate copied array.
+    deallocate_array((void*) &c, (void*) &cs, (void*) CHARACTER_ARRAY);
+}
+
+/**
+ * Tests the wide character output on linux console,
+ * in between escape control sequences.
+ */
+void test_wide_character_output() {
+
+    fputs("Test wide character array with termination:\n", stdout);
+
+#ifdef LINUX_OPERATING_SYSTEM
+    // Possible locales are: LANG, LC_CTYPE, LC_ALL.
+    // CAUTION! This setting is necessary for UTF-8 Unicode characters to work.
+    char* loc = setlocale(LC_ALL, "");
+
+    // The terminal (device name).
+    FILE* t = NULL_POINTER;
+    // The original termios interface.
+    struct termios* to = NULL_POINTER;
+    // The working termios interface.
+    struct termios* tw = NULL_POINTER;
+
+    // Create linux console internals.
+//??        allocate((void*) &t, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+    to = (struct termios*) malloc(sizeof(struct termios));
+    tw = (struct termios*) malloc(sizeof(struct termios));
+
+    // Initialise linux console internals.
+    // Set file stream.
+    // CAUTION! Possibly, stdin must be used instead of stdout here!
+    t = stdout;
+
+    // Get file descriptor for file stream.
+    int d = fileno(t);
+    // Copy termios attributes from file descriptor.
+    tcgetattr(d, (void*) to);
+    tcgetattr(d, (void*) tw);
+    // Manipulate termios attributes.
+    tw->c_lflag &= ~ICANON;
+    tw->c_lflag &= ~ECHO;
+    // Set termios attributes.
+    tcsetattr(d, TCSANOW, (void*) tw);
+
+    // The terminated control sequences string.
+    void* ts = NULL_POINTER;
+    int tsc = 0;
+    int tss = 100;
+
+    // Create terminated control sequences string.
+    allocate_array((void*) &ts, (void*) &tss, (void*) WIDE_CHARACTER_ARRAY);
+
+    // Set terminated control sequences string by first copying the actual
+    // control sequences and then adding the null termination character.
+    // (Termination character does not seem to be necessary for wide character strings.)
+    set_array_elements(ts, (void*) &tsc, (void*) BOX_DRAWINGS_LIGHT_DOWN_AND_RIGHT_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) WIDE_CHARACTER_ARRAY);
+    tsc++;
+    set_array_elements(ts, (void*) &tsc, (void*) BOX_DRAWINGS_LIGHT_HORIZONTAL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) WIDE_CHARACTER_ARRAY);
+    tsc++;
+
+    // printf("\033[32mgreen colour\033[0mswitched off.")
+
+    // \033
+    wchar_t wc = 0x001B;
+    set_array_elements(ts, (void*) &tsc, (void*) &wc, (void*) PRIMITIVE_COUNT, (void*) WIDE_CHARACTER_ARRAY);
+    tsc++;
+    // [
+    wc = 0x005B;
+    set_array_elements(ts, (void*) &tsc, (void*) &wc, (void*) PRIMITIVE_COUNT, (void*) WIDE_CHARACTER_ARRAY);
+    tsc++;
+    // 3
+    wc = 0x0033;
+    set_array_elements(ts, (void*) &tsc, (void*) &wc, (void*) PRIMITIVE_COUNT, (void*) WIDE_CHARACTER_ARRAY);
+    tsc++;
+    // 2
+    wc = 0x0032;
+    set_array_elements(ts, (void*) &tsc, (void*) &wc, (void*) PRIMITIVE_COUNT, (void*) WIDE_CHARACTER_ARRAY);
+    tsc++;
+    // m
+    wc = 0x006d;
+    set_array_elements(ts, (void*) &tsc, (void*) &wc, (void*) PRIMITIVE_COUNT, (void*) WIDE_CHARACTER_ARRAY);
+    tsc++;
+
+    set_array_elements(ts, (void*) &tsc, (void*) BOX_DRAWINGS_LIGHT_HORIZONTAL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) WIDE_CHARACTER_ARRAY);
+    tsc++;
+    set_array_elements(ts, (void*) &tsc, (void*) BOX_DRAWINGS_LIGHT_DOWN_AND_LEFT_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) WIDE_CHARACTER_ARRAY);
+    tsc++;
+
+    // Write to terminal.
+    fprintf(t, "%ls", (wchar_t*) ts);
+//??    fputws((wchar_t*) ts, t);
+
+    // Destroy terminated control sequences.
+    deallocate_array((void*) &ts, (void*) &tss, (void*) WIDE_CHARACTER_ARRAY);
+
+    // UTF-8 still allows you to use C1 control characters such as CSI, even
+    // though UTF-8 also uses bytes in the range 0x80-0x9F. It is important to
+    // understand that a terminal emulator in UTF-8 mode must apply the UTF-8
+    // decoder to the incoming byte stream before interpreting any control
+    // characters. C1 characters are UTF-8 decoded just like any other character
+    // above U+007F.
+    // VT100 terminal emulators accept ISO 2022 (=ECMA-35) ESC sequences in
+    // order to switch between different character sets.
+
+/*??
+    char c = 67;
+
+    if (c < 0x80) {
+
+        putchar(c);
+
+    } else if (c < 0x800) {
+
+        putchar(0xC0 | c >> 6);
+        putchar(0x80 | c & 0x3F);
+
+    } else if (c < 0x10000) {
+
+        putchar(0xE0 | c >> 12);
+        putchar(0x80 | c >> 6 & 0x3F);
+        putchar(0x80 | c & 0x3F);
+
+    } else if (c < 0x200000) {
+
+        putchar(0xF0 | c >> 18);
+        putchar(0x80 | c >> 12 & 0x3F);
+        putchar(0x80 | c >> 6 & 0x3F);
+        putchar(0x80 | c & 0x3F);
+    }
+*/
+#endif
+}
+
+/**
+ * Tests the integer-to-wide character conversion.
+ */
+void test_integer_to_wide_character_conversion() {
+
+    fputs("Test integer-to-wide character conversion:\n", stdout);
+
+    // The test wide character array.
+    void* t = NULL_POINTER;
+    int tc = 0;
+    // One byte for the wide character and another for the trailing null.
+    size_t ts = 2;
+
+    // Allocate test wide character array.
+    allocate((void*) &t, (void*) &ts, (void*) WIDE_CHARACTER_VECTOR_ABSTRACTION, (void*) WIDE_CHARACTER_VECTOR_ABSTRACTION_COUNT);
+
+    // Transform source integer to destination string.
+    // A null wide character is written to mark the end of the string.
+    // The return value is the number of characters generated
+    // for the given input, excluding the trailing null.
+    // If not all output fits into the provided buffer,
+    // a negative value is returned.
+#ifdef CYGWIN_ENVIRONMENT
+    tc = wsprintfW((wchar_t*) t, L"%i", 2);
+/* CYGWIN_ENVIRONMENT */
+#else
+    tc = swprintf((wchar_t*) t, ts, L"%i", 2);
+/* CYGWIN_ENVIRONMENT */
+#endif
+
+    fprintf(stdout, "TEST tc %i\n", tc);
+
+    // Deallocate test wide character array.
+    deallocate((void*) &t, (void*) &ts, (void*) WIDE_CHARACTER_VECTOR_ABSTRACTION, (void*) WIDE_CHARACTER_VECTOR_ABSTRACTION_COUNT);
+}
+
+/**
+ * Tests the ascii character - wide character equality.
+ */
+void test_ascii_character_wide_character_equality() {
+
+    fputs("Test ascii character - wide character equality:\n", stdout);
+
+    char test = 'a';
+
+    if (test = *LATIN_SMALL_LETTER_A_CHARACTER) {
+
+        fputs("Characters ARE equal.\n", stdout);
+
+    } else {
+
+        fputs("Characters are NOT equal.\n", stdout);
+    }
+}
+
 /**
  * Tests the pointer cast.
  */
@@ -108,11 +406,11 @@ void test_character_array_single_element() {
     // Create character array.
     allocate_array((void*) &c, (void*) &cs, (void*) CHARACTER_ARRAY);
 
-    set_character_array_elements(c, (void*) NUMBER_0_INTEGER, (void*) LATIN_CAPITAL_LETTER_A_CHARACTER, (void*) CHARACTER_COUNT);
-    set_character_array_elements(c, (void*) NUMBER_1_INTEGER, (void*) LATIN_CAPITAL_LETTER_B_CHARACTER, (void*) CHARACTER_COUNT);
-    set_character_array_elements(c, (void*) NUMBER_2_INTEGER, (void*) LATIN_CAPITAL_LETTER_C_CHARACTER, (void*) CHARACTER_COUNT);
-    set_character_array_elements(c, (void*) NUMBER_3_INTEGER, (void*) LINE_FEED_CONTROL_CHARACTER, (void*) CHARACTER_COUNT);
-    set_character_array_elements(c, (void*) NUMBER_4_INTEGER, (void*) NULL_CONTROL_CHARACTER, (void*) CHARACTER_COUNT);
+    set_character_array_elements(c, (void*) NUMBER_0_INTEGER, (void*) LATIN_CAPITAL_LETTER_A_CHARACTER, (void*) PRIMITIVE_COUNT);
+    set_character_array_elements(c, (void*) NUMBER_1_INTEGER, (void*) LATIN_CAPITAL_LETTER_B_CHARACTER, (void*) PRIMITIVE_COUNT);
+    set_character_array_elements(c, (void*) NUMBER_2_INTEGER, (void*) LATIN_CAPITAL_LETTER_C_CHARACTER, (void*) PRIMITIVE_COUNT);
+    set_character_array_elements(c, (void*) NUMBER_3_INTEGER, (void*) LINE_FEED_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT);
+    set_character_array_elements(c, (void*) NUMBER_4_INTEGER, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT);
 
     // Print out array contents.
     fputs((char*) c, stdout);
@@ -464,40 +762,43 @@ void test_integer_parser() {
 }
 
 /**
- * Tests the knowledge model.
+ * Tests the knowledge memory.
  *
- * The knowledge model is the root of a compound (tree).
- * But also a part of the knowledge model can be handed over,
- * in which case that part and its parts will be printed on screen.
+ * The knowledge memory is the root of a compound (tree).
+ * But also a compound element of the knowledge memory can be handed over,
+ * in which case that element and its parts will be printed on screen.
  *
- * @param p0 the knowledge model
- * @param p1 the knowledge model count
- * @param level the level for the tree
+ * @param p0 the knowledge memory or compound element
+ * @param p1 the knowledge memory or compound element count
+ * @param p2 the tree depth to be displayed
  */
-void test_knowledge_model(void* p0, void* p1, int level) {
-
-    fputs("Test knowledge model:\n", stdout);
-
-    char prefix[level * 3 + 1];
-    int level_count;
-    int char_count;
-
-    for (level_count = 0; level_count < level; level_count++) {
-
-        for (char_count = 0; char_count <= 2; char_count++) {
-
-            prefix[level_count * 3 + char_count] = '_';
-        }
-    }
-
-    prefix[level * 3] = '\0';
-    level++;
+void test_knowledge_memory(void* p0, void* p1, int p2) {
 
     if (p1 != NULL_POINTER) {
 
-        int* c = (int*) p1;
+        int* kc = (int*) p1;
 
-        // The loop index.
+        fputs("Test knowledge memory:\n", stdout);
+
+        // Create prefix.
+        char prefix[p2 * 2 + 1];
+        int level_count;
+        int char_count;
+
+        // Add underscores to prefix.
+        for (level_count = 0; level_count < p2; level_count++) {
+
+            for (char_count = 0; char_count <= 2; char_count++) {
+
+                prefix[level_count * 3 + char_count] = '_';
+            }
+        }
+
+        // Terminate prefix.
+        prefix[p2 * 2] = '\0';
+        p2++;
+
+        // The loop count.
         int i = 0;
         // The element name.
         void** n = &NULL_POINTER;
@@ -520,7 +821,7 @@ void test_knowledge_model(void* p0, void* p1, int level) {
 
         while (1) {
 
-            if (i >= *c) {
+            if (i >= *kc) {
 
                 break;
             }
@@ -536,12 +837,12 @@ void test_knowledge_model(void* p0, void* p1, int level) {
                 (void*) &d, (void*) &dc, (void*) &ds);
 
             // Print element name.
-            fprintf(stderr, "name:              %s%s\n", prefix, *n);
+            fprintf(stderr, "name:              %s%s\n", prefix, (char*) *n);
             fprintf(stderr, "name count:        %s%i\n", prefix, **((int**) nc));
             fprintf(stderr, "name size:         %s%i\n", prefix, **((int**) ns));
 
             // Print element abstraction.
-            fprintf(stderr, "abstraction:       %s%s\n", prefix, *a);
+            fprintf(stderr, "abstraction:       %s%s\n", prefix, (char*) *a);
             fprintf(stderr, "abstraction count: %s%i\n", prefix, **((int**) ac));
             fprintf(stderr, "abstraction size:  %s%i\n", prefix, **((int**) as));
 
@@ -553,7 +854,7 @@ void test_knowledge_model(void* p0, void* p1, int level) {
                 if (r == 1) {
 
                     fprintf(stderr, "model (compound): %s\n", "hierarchical, see below");
-                    test_knowledge_model((void*) *m, (void*) *mc, level);
+                    test_knowledge_memory((void*) *m, (void*) *mc, p2);
                 }
             }
 
@@ -569,6 +870,18 @@ void test_knowledge_model(void* p0, void* p1, int level) {
                 }
             }
 
+            if (r != 1) {
+
+                compare_arrays((void*) *a, (void*) *ac, (void*) KNOWLEDGE_ABSTRACTION, (void*) KNOWLEDGE_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+
+                if (r == 1) {
+
+                    fprintf(stderr, "model (knowledge):             %s\n", (char*) *m);
+                    fprintf(stderr, "model (knowledge) count:       %i\n", **((int**) mc));
+                    fprintf(stderr, "model (knowledge) size:        %i\n", **((int**) ms));
+                }
+            }
+
             if (r != 1) {
 
                 compare_arrays((void*) *a, (void*) *ac, (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
@@ -595,25 +908,25 @@ void test_knowledge_model(void* p0, void* p1, int level) {
             if (d != NULL_POINTER) {
 
                 fprintf(stderr, "details: %s\n", "hierarchical, see below");
-                test_knowledge_model((void*) *d, (void*) *dc, level);
+                test_knowledge_memory((void*) *d, (void*) *dc, p2);
             }
 
             // Reset element name.
-            n = NULL_POINTER;
-            nc = NULL_POINTER;
-            ns = NULL_POINTER;
+            n = &NULL_POINTER;
+            nc = &NULL_POINTER;
+            ns = &NULL_POINTER;
             // Reset element abstraction.
-            a = NULL_POINTER;
-            ac = NULL_POINTER;
-            as = NULL_POINTER;
+            a = &NULL_POINTER;
+            ac = &NULL_POINTER;
+            as = &NULL_POINTER;
             // Reset element model.
-            m = NULL_POINTER;
-            mc = NULL_POINTER;
-            ms = NULL_POINTER;
+            m = &NULL_POINTER;
+            mc = &NULL_POINTER;
+            ms = &NULL_POINTER;
             // Reset element details.
-            d = NULL_POINTER;
-            dc = NULL_POINTER;
-            ds = NULL_POINTER;
+            d = &NULL_POINTER;
+            dc = &NULL_POINTER;
+            ds = &NULL_POINTER;
             // Reset comparison result.
             r = 0;
 
@@ -622,45 +935,10 @@ void test_knowledge_model(void* p0, void* p1, int level) {
 
     } else {
 
-        fputs("ERROR: Could not test knowledge model. The knowledge model is null.\n", stdout);
+        fputs("ERROR: Could not test knowledge memory. The knowledge memory is null.\n", stdout);
     }
 }
 
-/**
- * Tests the compound.
- *
- * @param p0 the compound
- * @param p1 the compound count
- * @param p2 the index
- */
-void test_compound(void* comp, int* comp_count, int* index) {
-
-    void** n = &NULL_POINTER;
-    void** nc = &NULL_POINTER;
-    void** ns = &NULL_POINTER;
-    void** a = &NULL_POINTER;
-    void** ac = &NULL_POINTER;
-    void** as = &NULL_POINTER;
-    void** m = &NULL_POINTER;
-    void** mc = &NULL_POINTER;
-    void** ms = &NULL_POINTER;
-    void** d = &NULL_POINTER;
-    void** dc = &NULL_POINTER;
-    void** ds = &NULL_POINTER;
-
-    get_compound_element_name_by_index(comp, comp_count, index,
-        &n, &nc, &ns);
-    get_compound_element_by_index(comp, comp_count, index,
-        &a, &ac, &as, &m, &mc, &ms, &d, &dc, &ds);
-
-    fprintf(stderr, "compound name:              %s\n", (char*) *n);
-    fprintf(stderr, "compound name count:        %i\n", *((int*) *nc));
-    fprintf(stderr, "compound abstraction:       %s\n", (char*) *a);
-    fprintf(stderr, "compound abstraction count: %i\n", *((int*) *ac));
-    fprintf(stderr, "compound model:             %s\n", (char*) *m);
-    fprintf(stderr, "compound model count:       %i\n", *((int*) *mc));
-}
-
 /**
  * The main test procedure.
  *
@@ -676,13 +954,19 @@ void test() {
     // int x = 2;
     // fprintf(stderr, "The value of x is: %d\n", x);
 
+//??    test_inline_assembler_code();
+//??    test_preprocessor_directives();
 //??    test_stdout_stderr();
 //??    test_character_array_with_termination();
+    test_array_resizing();
+//??    test_wide_character_output();
+//??    test_integer_to_wide_character_conversion();
+//??    test_ascii_character_wide_character_equality();
 //??    test_pointer_cast();
 //??    test_character_array_single_element();
 //??    test_character_array_multiple_elements();
 //??    test_pointer_return();
-    test_pointer_array();
+//??    test_pointer_array();
 //??    test_file_read();
 //??    test_file_write();
 //??    test_console();
